/*
    Theseus - maximum likelihood superpositioning of macromolecular structures

    Copyright (C) 2004-2014 Douglas L. Theobald

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the:

    Free Software Foundation, Inc.,
    59 Temple Place, Suite 330,
    Boston, MA  02111-1307  USA

    -/_|:|_|_\-
*/

#ifndef MULTIPOSE_SEEN
#define MULTIPOSE_SEEN

#include "Cds.h"

void
CalcTranslationsIp(CdsArray *scratchA, Algorithm *algo);

double
CalcRotations(CdsArray *cdsA);

void
HierarchVars(CdsArray *cdsA);

int
CheckConvergenceInner(CdsArray *cdsA, const double precision);

int
CheckConvergenceOuter(CdsArray *cdsA, int round, const double precision);

void
InitializeStates(CdsArray *cdsA);

int
MultiPose(CdsArray *baseA);

int
MultiPose_pth(CdsArray *baseA);

void
CalcWts(CdsArray *cdsA);

#endif
